**Example 1: 删除单元化规则**

删除单元化规则

Input: 

```
tccli tsf DeleteApiRateLimitRule --cli-unfold-argument  \
    --RuleId abc
```

Output: 
```
{
    "Response": {
        "Result": true,
        "RequestId": "abc"
    }
}
```

